<?php

/**
 * @file
 *
 * Theme functions
 */

/**
 * Logo, Site Name, Site Slogan
 */
function om_identity($logo, $site_name, $site_slogan, $front_page) {
  if (!empty($logo) || !empty($site_name) || !empty($site_slogan)) { 
    $out = '<div id="logo-title">';
    if (!empty($logo)) { 
      $out .= '<a href="' . $front_page . '" title="' . t('Home') . '" rel="home" id="logo">';
      $out .= '<img src="' . $logo . '" alt="' . t('Home') . '" />';
      $out .= '</a>';
    }
    if (!empty($site_name) || !empty($site_slogan)) { 
      $out .= '<div id="name-and-slogan">';
      if (!empty($site_name)) {
        $out .= '<h1 id="site-name">';
        $out .= '<a href="' . $front_page . '" title="' . t('Home') . '" rel="home">' . $site_name . '</a>';
        $out .= '</h1>';
      }
      if (!empty($site_slogan)) {
        $out .= '<div id="site-slogan">' . $site_slogan . '</div>';
      }
      $out .= '</div> <!-- /#name-and-slogan -->';
    }    
    $out .= '</div> <!-- /#logo-title -->';
    return $out;
  }
}


/**
 * Primary, Secondary Menus
 *
function om_menu($menu_name = NULL, $menu = NULL, $menu_tree = NULL) {
	if(!empty($menu)) { 
			return '<div id="menubar-' . $menu_name. '" class="menubar">' . $menu_tree . '</div>';
  }
}

/**
 * Process all region formats
 */
function om_region_wrapper($region_name = NULL, $region = NULL, $region_inner = 0) {
  if ($region) { 
    if ($region_inner == 1) { 
      $div_prefix = '<div id="' . $region_name . '" class="region"><div id="' . $region_name . '-inner" class="region-inner">'; 
      $div_suffix = '<div class="om-clearfix"></div></div><!-- /#' . $region_name . '-inner --></div><!-- /#' . $region_name . ' -->'; 
    }
    else {
      $div_prefix = '<div id="' . $region_name . '" class="region">'; 
      $div_suffix = '<div class="om-clearfix"></div></div><!-- /#' . $region_name . ' -->'; 
    }
    return $div_prefix . $region . $div_suffix;
  }
}

/**
 * Returns HTML for a breadcrumb trail.
 *
 * @param $variables
 *   An associative array containing:
 *   - breadcrumb: An array containing the breadcrumb links.
 */
function om_breadcrumb($variables) {
  $breadcrumb = $variables['breadcrumb'];

  if (!empty($breadcrumb)) {
    // Provide a navigational heading to give context for breadcrumb links to
    // screen-reader users. Make the heading invisible with .element-invisible.
    $output = '<h2 class="element-invisible">' . t('You are here') . '</h2>';

    $output .= '<div class="breadcrumb">' . implode(' » ', $breadcrumb) . '</div>';
    return $output;
  }
}


/**
 * Process all content elements
 */
function om_content_elements($tabs = NULL, $prefix = NULL, $title = NULL, $suffix = NULL, $messages = NULL, $help = NULL, $action = NULL) {
  $out = '';
  if (!empty($tabs)) { 
    $out .= '<div class="tabs">' . $tabs . '</div>'; 
  }
  if (!empty($prefix)) { 
    $out .= $prefix; 
  }
  if (!empty($title)) { 
    $out .= '<h1 class="title" id="page-title">' . $title . '</h1>'; 
  }
  if (!empty($suffix)) { 
    $out .= $suffix; 
  }
  if (!empty($messages)) { 
    $out .= $messages; 
  }
  if (!empty($help)) { 
    $out .= $help; 
  }
  if (!empty($action)) { 
    $out .= '<ul class="action-links">' . $action . '</ul>'; 
  }
  return $out;
}

/**
 * Process variables for html.tpl.php
 *
 * Perform final addition and modification of variables before passing into
 * the template. To customize these variables, call drupal_render() on elements
 * in $variables['page'] during THEME_preprocess_page().
 *
 * @see template_preprocess_html()
 * @see html.tpl.php
 */
function om_process_html(&$variables) {
  $variables['page_bottom'] .= '<div id="legal">OM Base Theme ' . date('Y') . ' | V7.x-1.x | <a href="http://www.danielhonrade.com">Daniel Honrade</a></div>';
}
 
/**
 * Adding first and last classes to blocks.
 * TODOs:
 * add block-last
 */
function om_preprocess_block(&$variables) {
  $block_counter = &drupal_static(__FUNCTION__, array());
  $variables['block'] = $variables['elements']['#block'];
  // All blocks get an independent counter for each region.
  if (!isset($block_counter[$variables['block']->region])) {
    $block_counter[$variables['block']->region] = 1;
    $variables['classes_array'][] = drupal_html_class('block-first');
  }
} 
 
/**
 * Generates IE CSS links for LTR and RTL languages.
 */

function om_get_ie_styles($ie) {
  global $language;
  global $theme; 
  switch ($ie) {
    case 'ie' : $ie_path = '/css/ie.css'; break;
    case 'ie6': $ie_path = '/css/ie6.css'; break;
    case 'ie7': $ie_path = '/css/ie7.css'; break;
    case 'ie8': $ie_path = '/css/ie8.css'; break;
    case 'ie9': $ie_path = '/css/ie9.css'; break;
    default   : $ie_path = '/css/ie8.css'; break;
  }
  $iecss = '<link type="text/css" rel="stylesheet" media="all" href="' . base_path() . drupal_get_path('theme', $theme) . $ie_path . '" />';
  if ($language->direction == LANGUAGE_RTL) {
    $iecss .= '<style type="text/css" media="all">@import "' . base_path() . drupal_get_path('theme', $theme) . '/css/ie-rtl.css";</style>';
  }
  return $iecss;
}
